==> django-admin-soft-dashboard-1.0.25.tar.gz: django-admin-soft-dashboard-1.0.25/README.md <==
# [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Django Integration

Modern template for **Django** built with **[Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/)**, an open-source `Bootstrap` UI Kit released by [Creative-Tim](https://app-generator.dev/agency/creative-tim/).

- [Django Admin Soft](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html) - Documentation & Support Links
- [Django Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Design Integration
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

## Pre-built Starters

### [Django Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/django/) `FREE`

> The FREE Version (MIT License) - [Live Demo](https://django-soft-dash.onrender.com/).

- Simple, Easy-to-Extend Codebase
- [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Design Integration
- Dynamic Tables
- Dynamic API
- Charts
- **CLI for Coding Tasks**
  - `Commit/rollback Git Changes`
  - `Backup & restore DB`
  - `Interact with Django Core` via CLI
  - `Update Environment variables`
  - `Update Dependencies`
- Bootstrap 5 Styling 
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- Vite for assets management 

![Django Soft Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap 5 Design.](https://github.com/user-attachments/assets/2dd7adf3-bf5f-4894-b585-3696e7a8606f)

<br />

### [Django Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard-pro/django/) `PRO`

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-soft-dash-pro.onrender.com/).

- Simple, Easy-to-Extend Codebase
- [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) PRO Design Integration
- Session-based Authentication, Password recovery
- OAuth (GitHub & Google)
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Apps
  - Charts
  - Server-Side Datatables
  - API via DRF
  - Extended Users Profile
  - Async Tasks (Celery)
- Docker 
- CI/CD integration for Render 

![Django Soft Dashboard PRO - Premium starter powered by Django and Bootstrap 5 - actively supported provided by App-Generator.](https://github.com/user-attachments/assets/828b0f83-1a37-4390-8685-411b4f408cdb)

<br />

## `Customize` with [Django App Generator](https://app-generator.dev/tools/django-generator/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

![Django Generator - User Interface for choosing the Design](https://github.com/user-attachments/assets/b989c434-1c53-49ff-8dda-b46dbfc142ac) 

![Django App Generator - User Interface for Edit the Extended User Model](https://github.com/user-attachments/assets/f1a5fb68-a5ba-49c9-a3ae-91716de09912) 

<br />

---
[Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Django Integration - Library provided by **[App-Generator](https://app-generator.dev)**

==> django-admin-soft-dashboard-1.0.26.tar.gz: django-admin-soft-dashboard-1.0.26/README.md <==
# [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Django Integration

Modern template for **Django** built with **[Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/)**, an open-source `Bootstrap` UI Kit released by [Creative-Tim](https://app-generator.dev/agency/creative-tim/).

- [Django Admin Soft](https://app-generator.dev/docs/products/django-libs/theme-soft-dashboard.html) - Documentation & Support Links
- [Django Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## Features

- [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Design Integration
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

## [Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Starters

Pre-built starters for coding dashboards and services (APIs, DataTables) with speed.

### [Django Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/django/)

> The FREE Version (MIT License) - [Live Demo](https://django-soft-dash.onrender.com/).

- Simple, Easy-to-Extend codebase
- [Soft UI Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Design Integration 
- [Bootstrap](https://app-generator.dev/docs/templates/bootstrap.html) CSS Styling 
- Dynamic Tables - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-datatables.html)
- Dynamic API - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-api.html)
- Charts
- [Django CLI Package](https://app-generator.dev/docs/developer-tools/django-cli/index.html)
    - [Commit/rollback Git Changes](https://app-generator.dev/docs/developer-tools/django-cli/git-interface.html)
    - `Backup & restore DB`
    - [Interact with Django Core](https://app-generator.dev/docs/developer-tools/django-cli/query-django.html)
    - `Manage Environment`
    - `Manage Dependencies`
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- [Vite](https://app-generator.dev/docs/technologies/vite/index.html) for assets management 

![Django Soft Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap 5 Design.](https://github.com/user-attachments/assets/2dd7adf3-bf5f-4894-b585-3696e7a8606f)

<br />

### [Django Soft Dashboard PRO](https://app-generator.dev/product/soft-ui-dashboard-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-soft-dash-pro.onrender.com/).

- Simple, Easy-to-Extend Codebase
- [Soft UI Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) PRO Design Integration 
- Bootstrap Styling 
- Dynamic Tables - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-datatables.html)
- Dynamic API - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-api.html)
- Charts
- Session-based Authentication, Password recovery
- OAuth (GitHub & Google)
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- [Django CLI Package](https://app-generator.dev/docs/developer-tools/django-cli/index.html)
    - [Commit/rollback Git Changes](https://app-generator.dev/docs/developer-tools/django-cli/git-interface.html)
    - `Backup & restore DB`
    - [Interact with Django Core](https://app-generator.dev/docs/developer-tools/django-cli/query-django.html)
    - `Manage Environment`
    - `Manage Dependencies`
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- [Vite](https://app-generator.dev/docs/technologies/vite/index.html) for assets management 

![Django Soft Dashboard PRO - Premium starter powered by Django and Bootstrap 5 - actively supported provided by App-Generator.](https://github.com/user-attachments/assets/828b0f83-1a37-4390-8685-411b4f408cdb)

<br />

## `Customize` with [Django App Generator](https://app-generator.dev/tools/django-generator/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

![Django Generator - User Interface for choosing the Design](https://github.com/user-attachments/assets/b989c434-1c53-49ff-8dda-b46dbfc142ac) 

![Django App Generator - User Interface for Edit the Extended User Model](https://github.com/user-attachments/assets/f1a5fb68-a5ba-49c9-a3ae-91716de09912) 

<br />

---
[Soft Dashboard](https://app-generator.dev/product/soft-ui-dashboard/) Django Integration - Library provided by **[App-Generator](https://app-generator.dev)**
